Merge 'master' into 'amd-master'
Change-Id: Ie37ee84b9c4f2808bd0dc2986e20feeb4449cea3
This commit is contained in:
@@ -92,5 +92,8 @@ namespace hip_impl
|
|||||||
|
|
||||||
delete static_cast<L*>(locked_stream);
|
delete static_cast<L*>(locked_stream);
|
||||||
locked_stream = nullptr;
|
locked_stream = nullptr;
|
||||||
|
if(HIP_PROFILE_API) {
|
||||||
|
MARKER_END();
|
||||||
|
}
|
||||||
}
|
}
|
||||||
}
|
}
|
||||||
|
|||||||
+1
-1
@@ -269,7 +269,7 @@ hipError_t hipCtxGetSharedMemConfig ( hipSharedMemConfig * pConfig )
|
|||||||
hipError_t hipCtxSynchronize ( void )
|
hipError_t hipCtxSynchronize ( void )
|
||||||
{
|
{
|
||||||
HIP_INIT_API(1);
|
HIP_INIT_API(1);
|
||||||
return ihipSynchronize(); //TODP Shall check validity of ctx?
|
return ihipLogStatus(ihipSynchronize()); //TODP Shall check validity of ctx?
|
||||||
}
|
}
|
||||||
|
|
||||||
hipError_t hipCtxGetFlags ( unsigned int* flags )
|
hipError_t hipCtxGetFlags ( unsigned int* flags )
|
||||||
|
|||||||
+3
-1
@@ -1592,7 +1592,9 @@ void ihipPostLaunchKernel(const char *kernelName, hipStream_t stream, grid_launc
|
|||||||
tprintf(DB_SYNC, "ihipPostLaunchKernel, unlocking stream\n");
|
tprintf(DB_SYNC, "ihipPostLaunchKernel, unlocking stream\n");
|
||||||
|
|
||||||
stream->lockclose_postKernelCommand(kernelName, lp.av);
|
stream->lockclose_postKernelCommand(kernelName, lp.av);
|
||||||
MARKER_END();
|
if(HIP_PROFILE_API) {
|
||||||
|
MARKER_END();
|
||||||
|
}
|
||||||
}
|
}
|
||||||
|
|
||||||
//=================================================================================================
|
//=================================================================================================
|
||||||
|
|||||||
Reference in New Issue
Block a user